(this.webpackJsonpstreamlit_component_template=this.webpackJsonpstreamlit_component_template||[]).push([[0],{153:function(e,a,t){e.exports=t(209)},209:function(e,a,t){"use strict";t.r(a);var r,n,i=t(10),c=t.n(i),o=t(99),s=t.n(o),l=t(7),d=t(81),p=t(0),m=t(1),u=t(2),b=t(3),g=t(68),h=t(69),f=t(50),v=t(245),x=t(145),j=t(147),w=t(146),O=t(144),y=t(248),k=(t(161),t(162),t(163),function(e){Object(u.a)(t,e);var a=Object(b.a)(t);function t(){var e;Object(m.a)(this,t);for(var i=arguments.length,o=new Array(i),s=0;s<i;s++)o[s]=arguments[s];return(e=a.call.apply(a,[this].concat(o))).render=function(){g.a.setFrameHeight(window.innerHeight);var a=e.props.args,t=a.isUser,i=a.avatarStyle,o=a.seed,s=a.message,p=a.allow_html,m=a.is_table,u="https://api.dicebear.com/5.x/".concat(i,"/svg?seed=").concat(o),b=e.props.theme;if(!b)return c.a.createElement("div",null,"Theme is undefined, please check streamlit version.");var k=h.a.img({border:"1px solid transparent",borderRadius:"50%",height:"3rem",width:"3rem",margin:0}),E=h.a.div({display:"inline-block",background:b.secondaryBackgroundColor,border:"1px solid transparent",borderRadius:"10px",padding:"10px 14px",margin:"5px 20px",maxWidth:"70%",whiteSpace:m?"normal":"pre-line"}),_=h.a.div({display:"flex",fontFamily:"".concat(b.font,", 'Segoe UI', 'Roboto', sans-serif"),height:"auto",margin:0,width:"100%"},(function(e){return e.isUser?Object(f.a)(r||(r=Object(d.a)(["\n          flex-direction: row-reverse;\n          & > div {\n            text-align: right;\n          }\n        "]))):Object(f.a)(n||(n=Object(d.a)([""])))})),S=[x.a,O.a],U=[j.a].concat(Object(l.a)(p?[w.a]:[]));return c.a.createElement(_,{isUser:t,className:"markdown-body"},c.a.createElement(k,{src:u,alt:"profile",draggable:"false"}),c.a.createElement(E,null,c.a.createElement(v.a,{remarkPlugins:S,rehypePlugins:[].concat(Object(l.a)(U),[[y.a,{detect:!0}]])},s)))},e}return Object(p.a)(t)}(g.b)),E=Object(g.c)(k);s.a.render(c.a.createElement(c.a.StrictMode,null,c.a.createElement(E,null)),document.getElementById("root"))}},[[153,1,2]]]);
//# sourceMappingURL=main.e9a08b4d.chunk.js.map